@@ -1,4 +1,4 @@
-from .post_ql import post, get_queries, headers
+from .post_ql import post, headers
 from typing import Dict, Any, List, Tuple, Callable as Function
 from .logging import logging
 from .utils.JSDict import JSDict
@@ -17,11 +17,12 @@ from .exceptions import InvalidSid
 
 class Track(BasicEventEmitter):
     def __init__(self, func: Function[..., Any], ms: int) -> None:
+        super()
         super().__init__()
         self.f = func
         self.ms = ms
         self.running = False
-        self.t = None
+        self.t = None 
     def start(self) -> None:
         if (self.running): return
         def call_func():
@@ -42,27 +43,22 @@ class Track(BasicEventEmitter):
 
 class Client(BasicEventEmitter):
     def __init__(self, sid: str) -> None:
+        super()
         super().__init__()
-        logging.log("fetching queries")
-        with open("queries.json", "w") as f:
-            req = get("https://Queries-Whitelist.bigminiboss.repl.co/")
-            f.write(req.text)
-        logging.log("finished fetching")
         
         self.sid = sid
         self.users = UserManager(self)
         self.repls = ReplManager(self)
         self.posts = PostManager(self, self)
         self.comments = CommentManager(self, self)
-        self.q = get_queries()
-        data = post(self.sid, self.q["currentUser"])
+        data = post(self.sid, "currentUser")
         if ("currentUser" not in data or data["currentUser"]): InvalidSid("SID invalid")
         vars = data["currentUser"]
         vars.update({"countryCode": data["country"]})
         self.user = CurrentUser(self)
         self.user.update(vars)
         self.users.cache[self.user.username] = self.user
-        data = post(self.sid, self.q["repl"], vars = {
+        data = post(self.sid, "repl", vars = {
             "id": environ["REPL_ID"]
         })
         self.repl = Repl(self)
@@ -77,7 +73,7 @@ class Client(BasicEventEmitter):
         options = JSDict(options)
         cache = options.cache
         del options["cache"]
-        res = post(self.sid, self.q["search"], vars = {"options": options})
+        res = post(self.sid, "search", vars = {"options": options})
         search = res["search"]
         results = {
             "repls": {},
@@ -116,7 +112,6 @@ class UserManager:
     def __init__(self, client) -> None:
         self.c = client
         self.cache = {}
-        self.q = get_queries()
 
     def fetch(self, userResolvable, options: Dict[str, Any] = {}):
         current = {"force": False, "cache": True}
@@ -137,12 +132,12 @@ class UserManager:
             return None
         if (not options.force):
             property = list(variables.keys())[0]
-            value = variables[property]
-            if ("user" in self.cache):
-                match = str(self.cache["user"][property]).lower()
+            var = variables[property]
+            if (var in self.cache):
+                match = str(self.cache[var]).lower()
                 return match
 
-        res = post(self.c.sid, self.q[query], variables)
+        res = post(self.c.sid, query, variables)
         if (not res[query]): return None
         user = User(self.c)
         user.update(res[query])
@@ -153,7 +148,7 @@ class UserManager:
         current = {"cache": True, "limit": 10}
         current.update(options)
         options = JSDict(current)
-        res = post(self.c.sid, self.q["userSearch"], vars = {
+        res = post(self.c.sid, "userSearch", vars = {
             "query": query,
             "limit": options.limit
         })
@@ -170,12 +165,11 @@ class UserEventManager:
     def __init__(self, client) -> None:
         self.c = client
         self.cache = {}
-        self.q = get_queries()
     def fetch(self, options: Dict[str, Any] = {}) -> Dict[str, Any]:
         current = {"cache": True, "limit": 10}
         current.update(options)
         options = JSDict(current)
-        res = post(self.c.sid, self.q["userEvents"], vars = {
+        res = post(self.c.sid, "userEvents", vars = {
             "count": options.limit,
             "after": ""
         })
@@ -193,17 +187,16 @@ class ReplManager:
         self.c = client
         self.cache = {}
         self.user = user
-        self.q = get_queries()
 
     def fetch(self, replResolvable = None, **kwargs):
-        if (self.user):
+        if (getattr(self, "user", False) and self.user):
             if (self.user == self.c.user):
                 options = {'cache': True, 'limit': 10, 'paths': ['']}
                 options.update(kwargs)
                 options = JSDict(options)
                 c = {}
                 for path in options.paths:
-                    res = post(self.c.sid, self.q["dashboardRepls"], vars = {
+                    res = post(self.c.sid, "dashboardRepls", vars = {
                         "path": path,
                         "count": options.limit
                     })
@@ -218,7 +211,7 @@ class ReplManager:
                 options = {"cache": True, "limit": 10, "search": None}
                 options.update(kwargs)
                 options = JSDict(options)
-                res = post(self.c.sid, self.q["profileRepls"], vars = {
+                res = post(self.c.sid, "profileRepls", vars = {
                     "username": self.user.username,
                     "count": options.limit
                 })
@@ -247,7 +240,7 @@ class ReplManager:
                 return None
             if (not options.force and "id" in vars and vars["id"] in self.cache):
                 return self.cache[vars["id"]]
-            res = post(self.c.sid, self.q["repl"], vars = vars)
+            res = post(self.c.sid, "repl", vars = vars)
             repl = Repl(self.c)
             repl.update(res["repl"])
             if (options.cache): self.cache[repl.id] = repl
@@ -255,7 +248,7 @@ class ReplManager:
             
 
     def generateTitle(self) -> str:
-        res = post(self.c.sid, self.q["replTitle"])
+        res = post(self.c.sid, "replTitle")
         return res["replTitle"]
 
     def create(self, options: Dict[str, Any] = {}):
@@ -264,7 +257,7 @@ class ReplManager:
         options = current
         cache = options["cache"]
         del options["cache"]
-        res = post(self.c.sid, self.q["createRepl"], vars = {
+        res = post(self.c.sid, "createRepl", vars = {
             "input": options
         })
         r = res["createRepl"]
@@ -283,20 +276,19 @@ class PostManager:
         self.c = client
         self.parent = parent
         self.cache = {}
-        self.q = get_queries()
 
     def fetch(self, **kwargs: Dict[str, Any]) -> None:
         res = None
         name = Switch(type(self.parent).__name__)
-        if (name.case("Client")):
+        if (name.case("Client") or name.case('Bot')):
             id = kwargs["id"]
             options = {"cache": True}
             options.update(kwargs)
             options = JSDict(options)
-            res = post(self.c.sid, self.q["post"], vars = {
+            res = post(self.c.sid, "post", vars = {
                 "id": id
             })
-            if (not res["post"]): return None
+            if ("post" not in res or not res["post"]): return None
             _post = Post(self.c)
             _post.update(res["post"])
             if (options.cache):
@@ -306,7 +298,7 @@ class PostManager:
             options = {"cache": True, "limit": 10, "order": "new"}
             options.update(kwargs)
             options = JSDict(options)
-            res = post(self.c.sid, self.q["userPosts"], vars = {
+            res = post(self.c.sid, "userPosts", vars = {
                 "username": self.parent.username,
                 "count": options.limit
             })
@@ -319,9 +311,9 @@ class PostManager:
                 c[_post.id] = _post
             return c
     def trending(self, options: Dict[str, Any] = {}) -> Dict[str, Any]:
-        if (type(self.parent).__name__ == "Client"): return None
+        if (type(self.parent).__name__ == "Client" or type(self.parent).__name__ == "Bot"): return None
         options = {"cache": True, "limit": 10, "tags": []}
-        res = post(self.c.sid, self.q["trending"], vars = {
+        res = post(self.c.sid, "trending", vars = {
             "options": {
                 "searchQuery": options.search,
                 "count": options.limit,
@@ -342,21 +334,19 @@ class NotificationManager:
     def __init__(self, client) -> None:
         self.c = client
         self.cache = {}
-        self.track = Track(lambda: self.c.user.notifications.fetch(), 60)
+        self.track = Track(lambda: self.c.user.notifications.fetch_all(), 60)
         def _(notifs) -> None:
             for i in notifs:
                 self.c.emit("notification", notifs[i])
-            if ("size" in notifs and notifs["size"]):
-                self.markAsRead()
+            if (len(notifs) > 0): self.markAsRead()
         
         self.track.on("update", _)
-        self.q = get_queries()
 
     def fetch(self, options: Dict[str, Any] = {}) -> None:
         current = {"cache": True, "seen": False, "limit": 10}
         current.update(options)
         options = JSDict(current)
-        res = post(self.c.sid, self.q["notifications"], vars = {
+        res = post(self.c.sid, "notifications", vars = {
             "count": options.limit,
             "seen": options.seen
         })
@@ -370,8 +360,33 @@ class NotificationManager:
             c[notification.id] = notification
         return c
 
+    def fetch_all(self, options: Dict[str, Any] = {}) -> None:
+        current = {"cache": True, "seen": False, "limit": 200}
+        current.update(options)
+        options = JSDict(current)
+        res = {
+            "notifications": {
+                "items": [None for i in range(options.limit)]
+            }
+        }
+        while len(res["notifications"]["items"]) >= options.limit:
+            res = post(self.c.sid, "notifications", vars = {
+                "count": options.limit,
+                "seen": options.seen
+            })
+            notifications = res["notifications"]["items"]
+            options.limit *= 10
+        c = {}
+        for n in notifications:
+            notification = Notification(self.c)
+            notification.update(n)
+            if (options.cache):
+                self.cache[notification.id] = notification
+            c[notification.id] = notification
+        return c
+    
     def markAsRead(self) -> None:
-        post(self.c.sid, self.q["markAsRead"])
+        post(self.c.sid, "markAsRead")
         self.c.user.notificationCount = 0
 
     def startEvents(self) -> None:
@@ -386,12 +401,11 @@ class MultiplayerManager:
         self.c = client
         self.cache = {}
         self.repl = repl
-        self.q = get_queries()
 
     def invite(self, userResolvable) -> None:
         user = self.c.users.fetch(userResolvable)
         if (not user): return None
-        post(self.c.sid, self.q["addMultiplayer"], vars = {
+        post(self.c.sid, "addMultiplayer", vars = {
             "username": user.username,
             "replId": self.repl.id,
             "type": "rw"
@@ -400,7 +414,7 @@ class MultiplayerManager:
     def remove(self, userResolvable) -> None:
         user = self.c.users.fetch(userResolvable)
         if (not user): return None
-        post(self.c.sid, self.q["removeMultiplayer"], vars = {
+        post(self.c.sid, "removeMultiplayer", vars = {
             "username": user.username,
             "replId": self.repl.id,
         })
@@ -411,13 +425,12 @@ class FollowingManager:
         self.user = user
         self.cache = {}
         self.events = UserEventManager(self.c)
-        self.q = get_queries()
 
     def fetch(self, options: Dict[str, Any] = {}) -> Dict[str, Any]:
         current = {"cache": True, "limit": 10}
         current.update(options)
         options = current
-        res = post(self.c.sid, self.q["follows"], vars = {
+        res = post(self.c.sid, "follows", vars = {
             "username": self.user.username,
             "count": options["limit"]
         })
@@ -435,7 +448,7 @@ class FollowingManager:
     def setFollowing(self, userResolvable, should_follow: bool = True, options: Dict[str, Any] = {"cache": True}) -> bool:
         user = self.c.users.fetch(userResolvable)
         if (not user): return False
-        res = post(self.c.sid, q["follow"], vars = {
+        res = post(self.c.sid, "follow", vars = {
             "input": {
                 "targetUserId": user.id,
                 "shouldFollow": should_follow
@@ -451,13 +464,12 @@ class FollowersManager:
         self.c = client
         self.cache = {}
         self.user = user
-        self.q = get_queries()
 
     def fetch(self, options: Dict[str, Any] = {}) -> Dict[str, Any]:
         current = {"cache": True, "limit": 10}
         current.update(options)
         options = JSDict(current)
-        res = post(self.c.sid, self.q["followers"], vars = {
+        res = post(self.c.sid, "followers", vars = {
             "username": self.user.username,
             "count": options.limit
         })
@@ -473,15 +485,14 @@ class FollowersManager:
         return c
 
 class CommentManager:
-    def __init__(self, client, parentComment) -> None:
+    def __init__(self, client, parent_class) -> None:
         self.c = client
         self.cache = {}
-        self.parent = parentComment
-        self.q = get_queries()
+        self.parent = parent_class
 
     def fetch(self, commentResolvable = None, **arguements: Dict[str, Any]):
         name = Switch(type(self.parent).__name__)
-        if (name.case("Client")):
+        if (name.case("Client") or name.case("Bot")):
             options = {"cache": True, "force": False}
             options.update(arguements)
             options = JSDict(options)
@@ -497,7 +508,7 @@ class CommentManager:
                 if (id in self.cache):
                     _comment = self.cache[id]
                     return _comment
-            res = post(self.c.sid, self.q["replComment"], vars = {
+            res = post(self.c.sid, "replComment", vars = {
                 "id": id
             })
             c = res["replComment"]
@@ -516,7 +527,7 @@ class CommentManager:
             options = {'cache': True, "limit": 10}
             options.update(arguements)
             options = JSDict(options)
-            res = post(self.c.sid, self.q["replComments"], vars = {
+            res = post(self.c.sid, "replComments", vars = {
                 "id": self.parent.id,
                 "count": options.limit
             })
@@ -535,7 +546,7 @@ class CommentManager:
         elif (name.case("CurrentUser") or name.case("User")):
             options = {"cache": True, "limit": 10}
             options.update(arguements)
-            res = post(self.c.sid, self.q["userComments"], vars = {
+            res = post(self.c.sid, "userComments", vars = {
                 "input": {
                     "userId": self.parent.id
                 }
@@ -553,7 +564,6 @@ class User:
         self.followers = FollowersManager(self.c, self)
         self.following = FollowingManager(self.c, self)
         self.posts = PostManager(self.c, self)
-        self.q = get_queries()
 
     def update(self, data: Dict[str, Any]):
         """update profile"""
@@ -573,7 +583,7 @@ class User:
 
     def set_follow(self, should_follow: bool = True) -> bool:
         """follow a user and return whether they are following you"""
-        res = post(self.c.sid, self.q["follow"], vars = {
+        res = post(self.c.sid, "follow", vars = {
             "input": {
                 "targetUserId": self.id,
                 "shouldFollow": should_follow and True
@@ -585,7 +595,7 @@ class User:
 
     def set_block(self, should_block: bool = True) -> bool:
         """blocks a user and return whether they are blocking you"""
-        res = post(self.c.sid, self.q["block"], vars = {
+        res = post(self.c.sid, "block", vars = {
             "input": {
                 "targetUserId": self.id,
                 "shouldFollow": should_block and True
@@ -606,7 +616,6 @@ class CurrentUser(User):
             "github": None,
             "facebook": None
         }
-        self.q = get_queries()
 
     def update(self, data: Dict[str, Any] = {}):
         """update profile"""
@@ -656,7 +665,7 @@ class CurrentUser(User):
                 }, headers = _headers)
                 if (data.status_code == 200):
                     options["profileImageId"] = data["data"]["id"]
-        res = post(self.c.sid, self.q["updateUser"], vars = {
+        res = post(self.c.sid, "updateUser", vars = {
             "input": options
         })
         self.update(res['updateCurrentUser'])
@@ -772,7 +781,6 @@ class Repl:
         self.threads = []
         self.multiplayer = MultiplayerManager(self.c, self)
         self.comments = CommentManager(self.c, self)
-        self.q = get_queries()
         self.env = Env()
 
     def update(self, data: Dict[str, Any] = {}):
@@ -816,7 +824,7 @@ class Repl:
 
     def fetchThreads(self, options: Dict[str, Any] = {"cache": True}) -> Dict[str, Any]:
         options = JSDict(options)
-        res = post(self.c.sid, self.q["replThreads"], vars = {
+        res = post(self.c.sid, "replThreads", vars = {
             "id": self.id
         })
         threads = res["repl"]["annotationAnchors"]
@@ -841,7 +849,7 @@ class Repl:
         options = current
         cache = options["cache"]
         del options["cache"]
-        res = post(self.c.sid, self.q["createRepl"], vars = {"input": options})
+        res = post(self.c.sid, "createRepl", vars = {"input": options})
         r = res["createRepl"]
         if (not r["id"]): return None
         repl = Repl(self.c)
@@ -850,13 +858,13 @@ class Repl:
         return repl
 
     def delete(self) -> None:
-        post(self.c.sid, self.q["deleteRepl"], vars = {
+        post(self.c.sid, "deleteRepl", vars = {
             "id": self.id
         })
 
     def change(self, options: Dict[str, Any] = {}):
         options.update({"id": self.id})
-        res = post(self.c.sid, self.q["updateRepl"], vars = {
+        res = post(self.c.sid, "updateRepl", vars = {
             "input": options
         })
         self.update(res["updateRepl"]["repl"])
@@ -864,7 +872,7 @@ class Repl:
 
     def comment(self, body: str, options: Dict[str, Any] = {"cache": True}):
         options = JSDict(options)
-        res = post(self.c.sid, self.q["sendReplComment"], vars = {
+        res = post(self.c.sid, "sendReplComment", vars = {
             "input": {
                 "body": body,
                 "replId": self.id
@@ -927,14 +935,13 @@ class Notification:
         if (notif_data["timeCreated"]): self.timeCreated = notif_data["timeCreated"]
         if (notif_data["creator"]): self.creator = self.c.users.fetch(notif_data["creator"])
         if (notif_data["replComment"]):
-            self.comment = self.c.comments.fetch(notif_data["replComment"]["id"], **notif_data["replComment"])
+            self.comment = self.c.comments.fetch(int(notif_data["replComment"]["id"]), **notif_data["replComment"])
         return self
 
 class Comment:
     def __init__(self, client, parent = None) -> None:
         self.c = client
         self.comments = []
-        self.q = get_queries()
         self.parentComment = parent
 
     def update(self, data: Dict[str, Any]):
@@ -954,9 +961,9 @@ class Comment:
                 setattr(self, i, data[i])
         if (comment_data["timeCreated"]): self.timeCreated = comment_data["timeCreated"]
         if (comment_data["timeUpdated"]): self.timeUpdated = comment_data["timeUpdated"]
-        if (comment_data["user"]): self.user = self.c.users.fetch(comment_data["user"])
+        if (comment_data["user"]): self.user = self.c.users.fetch(comment_data["user"]["username"])
         if (comment_data["repl"]): self.repl = self.c.repls.fetch(comment_data["repl"])
-        if (comment_data["post"]): self.post = self.c.post.fetch(comment_data["post"])
+        if (comment_data["post"]): self.post = self.c.posts.fetch(**comment_data["post"])
         if (comment_data["parentComment"]):
             parent = comment_data["parentComment"]
             if (parent["id"] in self.c.comments.cache):
@@ -985,7 +992,7 @@ class Comment:
         """delete comment"""
         if ("delete" not in self.currentUserPermission): self.currentUserPermission["delete"] = None
         if (self.currentUserPermission["delete"] or self.isAuthor or self.repl.isOwner):
-            post(self.c.sid, self.q["deleteComment"], vars = {
+            post(self.c.sid, "deleteComment", vars = {
                 "id": self.id
             })
 
@@ -994,7 +1001,7 @@ class Comment:
         current = {"cache": True}
         current.update(options)
         options = JSDict(current)
-        res = post(self.c.sid, self.q["sendReplCommentReply"], vars = {
+        res = post(self.c.sid, "sendReplCommentReply", vars = {
             "input": {
                 "body": (f"@{self.user.username} {body}" if (getattr(options, "mention", False) and options.mention) else body),
                 "replCommentId": self.id
@@ -1005,5 +1012,4 @@ class Comment:
         comment.update(res['createReplCommentReply'])
         if (options.cache):
             self.c.comments.cache[comment.id] = comment
-        return comment
-
+        return comment
\ No newline at end of file
