@@ -4,9 +4,10 @@ import json
 from requests import post as _post, get as _get, delete as _delete
 from typing import Dict, Any
 from .logging import logging
+from .queries import q
 
 def get_queries() -> Dict[str, Any]:
-    return json.load(open('queries.json'))
+    return q
 
 end = "https://replit.com/graphql"
 headers = {
